import { writeFile, writeFileSync } from "fs";
import { GraphQLSchema, printSchema } from "graphql";
import { Options as PrintSchemaOptions } from "graphql/utilities/schemaPrinter";
import * as path from "path";

export const defaultSchemaFilePath = path.resolve(process.cwd(), "schema.gql");

const generatedSchemaWarning = /* graphql */ `\
# -----------------------------------------------
# !!! THIS FILE WAS GENERATED BY TYPE-GRAPHQL !!!
# !!!   DO NOT MODIFY THIS FILE BY YOURSELF   !!!
# -----------------------------------------------

`;

export function emitSchemaDefinitionFileSync(
  schemaFilePath: string,
  schema: GraphQLSchema,
  options: PrintSchemaOptions = { commentDescriptions: true },
) {
  const schemaFileContent = generatedSchemaWarning + printSchema(schema, options);
  writeFileSync(schemaFilePath, schemaFileContent);
}

export async function emitSchemaDefinitionFile(
  schemaFilePath: string,
  schema: GraphQLSchema,
  options: PrintSchemaOptions = { commentDescriptions: true },
) {
  const schemaFileContent = generatedSchemaWarning + printSchema(schema, options);
  return new Promise<void>((resolve, reject) =>
    writeFile(schemaFilePath, schemaFileContent, err => (err ? reject(err) : resolve())),
  );
}
